==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/PROMPTDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour PROMPTDETAILS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PROMPTDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROMPTDATATYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROMPTDESCRIPTION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FIXEDDATA" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COMPUTEDDATA" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PATTERNMATCH" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEFORMATMASK" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROMPTSEQUENCE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NEXTPROMPT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MINIMUMSIZE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MAXIMUMSIZE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DUPLICATEPREVIOUSVALUE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BRANCHCONDITIONDETAILS" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PROMPTDETAILS_Type", propOrder = {
    "promptdatatype",
    "promptdescription",
    "fixeddata",
    "computeddata",
    "patternmatch",
    "dateformatmask",
    "promptsequence",
    "nextprompt",
    "minimumsize",
    "maximumsize",
    "duplicatepreviousvalue",
    "branchconditiondetails"
})
public class PROMPTDETAILS_Type {

    @XmlElement(name = "PROMPTDATATYPE", required = true)
    protected TYPE_Type promptdatatype;
    @XmlElement(name = "PROMPTDESCRIPTION", required = true)
    protected String promptdescription;
    @XmlElement(name = "FIXEDDATA")
    protected String fixeddata;
    @XmlElement(name = "COMPUTEDDATA")
    protected String computeddata;
    @XmlElement(name = "PATTERNMATCH")
    protected String patternmatch;
    @XmlElement(name = "DATEFORMATMASK")
    protected String dateformatmask;
    @XmlElement(name = "PROMPTSEQUENCE")
    protected Long promptsequence;
    @XmlElement(name = "NEXTPROMPT")
    protected Long nextprompt;
    @XmlElement(name = "MINIMUMSIZE")
    protected Long minimumsize;
    @XmlElement(name = "MAXIMUMSIZE")
    protected Long maximumsize;
    @XmlElement(name = "DUPLICATEPREVIOUSVALUE")
    protected String duplicatepreviousvalue;
    @XmlElement(name = "BRANCHCONDITIONDETAILS")
    protected BRANCHCONDITIONDETAILS_Type branchconditiondetails;

    /**
     * Obtient la valeur de la propriété promptdatatype.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getPROMPTDATATYPE() {
        return promptdatatype;
    }

    /**
     * Définit la valeur de la propriété promptdatatype.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setPROMPTDATATYPE(TYPE_Type value) {
        this.promptdatatype = value;
    }

    /**
     * Obtient la valeur de la propriété promptdescription.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROMPTDESCRIPTION() {
        return promptdescription;
    }

    /**
     * Définit la valeur de la propriété promptdescription.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROMPTDESCRIPTION(String value) {
        this.promptdescription = value;
    }

    /**
     * Obtient la valeur de la propriété fixeddata.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFIXEDDATA() {
        return fixeddata;
    }

    /**
     * Définit la valeur de la propriété fixeddata.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFIXEDDATA(String value) {
        this.fixeddata = value;
    }

    /**
     * Obtient la valeur de la propriété computeddata.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOMPUTEDDATA() {
        return computeddata;
    }

    /**
     * Définit la valeur de la propriété computeddata.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOMPUTEDDATA(String value) {
        this.computeddata = value;
    }

    /**
     * Obtient la valeur de la propriété patternmatch.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPATTERNMATCH() {
        return patternmatch;
    }

    /**
     * Définit la valeur de la propriété patternmatch.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPATTERNMATCH(String value) {
        this.patternmatch = value;
    }

    /**
     * Obtient la valeur de la propriété dateformatmask.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDATEFORMATMASK() {
        return dateformatmask;
    }

    /**
     * Définit la valeur de la propriété dateformatmask.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDATEFORMATMASK(String value) {
        this.dateformatmask = value;
    }

    /**
     * Obtient la valeur de la propriété promptsequence.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getPROMPTSEQUENCE() {
        return promptsequence;
    }

    /**
     * Définit la valeur de la propriété promptsequence.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setPROMPTSEQUENCE(Long value) {
        this.promptsequence = value;
    }

    /**
     * Obtient la valeur de la propriété nextprompt.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getNEXTPROMPT() {
        return nextprompt;
    }

    /**
     * Définit la valeur de la propriété nextprompt.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setNEXTPROMPT(Long value) {
        this.nextprompt = value;
    }

    /**
     * Obtient la valeur de la propriété minimumsize.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getMINIMUMSIZE() {
        return minimumsize;
    }

    /**
     * Définit la valeur de la propriété minimumsize.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setMINIMUMSIZE(Long value) {
        this.minimumsize = value;
    }

    /**
     * Obtient la valeur de la propriété maximumsize.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getMAXIMUMSIZE() {
        return maximumsize;
    }

    /**
     * Définit la valeur de la propriété maximumsize.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setMAXIMUMSIZE(Long value) {
        this.maximumsize = value;
    }

    /**
     * Obtient la valeur de la propriété duplicatepreviousvalue.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDUPLICATEPREVIOUSVALUE() {
        return duplicatepreviousvalue;
    }

    /**
     * Définit la valeur de la propriété duplicatepreviousvalue.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDUPLICATEPREVIOUSVALUE(String value) {
        this.duplicatepreviousvalue = value;
    }

    /**
     * Obtient la valeur de la propriété branchconditiondetails.
     * 
     * @return
     *     possible object is
     *     {@link BRANCHCONDITIONDETAILS_Type }
     *     
     */
    public BRANCHCONDITIONDETAILS_Type getBRANCHCONDITIONDETAILS() {
        return branchconditiondetails;
    }

    /**
     * Définit la valeur de la propriété branchconditiondetails.
     * 
     * @param value
     *     allowed object is
     *     {@link BRANCHCONDITIONDETAILS_Type }
     *     
     */
    public void setBRANCHCONDITIONDETAILS(BRANCHCONDITIONDETAILS_Type value) {
        this.branchconditiondetails = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_fields/PROMPTDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PROMPTDETAILS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="PROMPTDETAILS_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PROMPTDATATYPE"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PROMPTDESCRIPTION"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}FIXEDDATA" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}COMPUTEDDATA" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PATTERNMATCH" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DATEFORMATMASK" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PROMPTSEQUENCE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}NEXTPROMPT" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MINIMUMSIZE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MAXIMUMSIZE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DUPLICATEPREVIOUSVALUE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}BRANCHCONDITIONDETAILS" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PROMPTDETAILS_Type", propOrder = {
    "promptdatatype",
    "promptdescription",
    "fixeddata",
    "computeddata",
    "patternmatch",
    "dateformatmask",
    "promptsequence",
    "nextprompt",
    "minimumsize",
    "maximumsize",
    "duplicatepreviousvalue",
    "branchconditiondetails"
})
public class PROMPTDETAILS_Type {

    @XmlElement(name = "PROMPTDATATYPE", required = true)
    protected TYPE_Type promptdatatype;
    @XmlElement(name = "PROMPTDESCRIPTION", required = true)
    protected String promptdescription;
    @XmlElement(name = "FIXEDDATA")
    protected String fixeddata;
    @XmlElement(name = "COMPUTEDDATA")
    protected String computeddata;
    @XmlElement(name = "PATTERNMATCH")
    protected String patternmatch;
    @XmlElement(name = "DATEFORMATMASK")
    protected String dateformatmask;
    @XmlElement(name = "PROMPTSEQUENCE")
    protected Long promptsequence;
    @XmlElement(name = "NEXTPROMPT")
    protected Long nextprompt;
    @XmlElement(name = "MINIMUMSIZE")
    protected Long minimumsize;
    @XmlElement(name = "MAXIMUMSIZE")
    protected Long maximumsize;
    @XmlElement(name = "DUPLICATEPREVIOUSVALUE")
    protected String duplicatepreviousvalue;
    @XmlElement(name = "BRANCHCONDITIONDETAILS")
    protected BRANCHCONDITIONDETAILS_Type branchconditiondetails;

    /**
     * Gets the value of the promptdatatype property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getPROMPTDATATYPE() {
        return promptdatatype;
    }

    /**
     * Sets the value of the promptdatatype property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setPROMPTDATATYPE(TYPE_Type value) {
        this.promptdatatype = value;
    }

    /**
     * Gets the value of the promptdescription property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROMPTDESCRIPTION() {
        return promptdescription;
    }

    /**
     * Sets the value of the promptdescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROMPTDESCRIPTION(String value) {
        this.promptdescription = value;
    }

    /**
     * Gets the value of the fixeddata property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFIXEDDATA() {
        return fixeddata;
    }

    /**
     * Sets the value of the fixeddata property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFIXEDDATA(String value) {
        this.fixeddata = value;
    }

    /**
     * Gets the value of the computeddata property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOMPUTEDDATA() {
        return computeddata;
    }

    /**
     * Sets the value of the computeddata property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOMPUTEDDATA(String value) {
        this.computeddata = value;
    }

    /**
     * Gets the value of the patternmatch property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPATTERNMATCH() {
        return patternmatch;
    }

    /**
     * Sets the value of the patternmatch property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPATTERNMATCH(String value) {
        this.patternmatch = value;
    }

    /**
     * Gets the value of the dateformatmask property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDATEFORMATMASK() {
        return dateformatmask;
    }

    /**
     * Sets the value of the dateformatmask property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDATEFORMATMASK(String value) {
        this.dateformatmask = value;
    }

    /**
     * Gets the value of the promptsequence property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getPROMPTSEQUENCE() {
        return promptsequence;
    }

    /**
     * Sets the value of the promptsequence property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setPROMPTSEQUENCE(Long value) {
        this.promptsequence = value;
    }

    /**
     * Gets the value of the nextprompt property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getNEXTPROMPT() {
        return nextprompt;
    }

    /**
     * Sets the value of the nextprompt property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setNEXTPROMPT(Long value) {
        this.nextprompt = value;
    }

    /**
     * Gets the value of the minimumsize property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getMINIMUMSIZE() {
        return minimumsize;
    }

    /**
     * Sets the value of the minimumsize property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setMINIMUMSIZE(Long value) {
        this.minimumsize = value;
    }

    /**
     * Gets the value of the maximumsize property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getMAXIMUMSIZE() {
        return maximumsize;
    }

    /**
     * Sets the value of the maximumsize property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setMAXIMUMSIZE(Long value) {
        this.maximumsize = value;
    }

    /**
     * Gets the value of the duplicatepreviousvalue property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDUPLICATEPREVIOUSVALUE() {
        return duplicatepreviousvalue;
    }

    /**
     * Sets the value of the duplicatepreviousvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDUPLICATEPREVIOUSVALUE(String value) {
        this.duplicatepreviousvalue = value;
    }

    /**
     * Gets the value of the branchconditiondetails property.
     * 
     * @return
     *     possible object is
     *     {@link BRANCHCONDITIONDETAILS_Type }
     *     
     */
    public BRANCHCONDITIONDETAILS_Type getBRANCHCONDITIONDETAILS() {
        return branchconditiondetails;
    }

    /**
     * Sets the value of the branchconditiondetails property.
     * 
     * @param value
     *     allowed object is
     *     {@link BRANCHCONDITIONDETAILS_Type }
     *     
     */
    public void setBRANCHCONDITIONDETAILS(BRANCHCONDITIONDETAILS_Type value) {
        this.branchconditiondetails = value;
    }

}
